CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
93 lines
2.4 KiB
C++
93 lines
2.4 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
|
|
constexpr size_t N = 1024;
|
|
int p_blockSize = 256;
|
|
|
|
__global__ void __launch_bounds__(256, 2) myKern(int* C, const int* A, int N) {
|
|
int tid = (blockIdx.x * blockDim.x + threadIdx.x);
|
|
|
|
if (tid < N) {
|
|
C[tid] = A[tid];
|
|
}
|
|
}
|
|
/**
|
|
* @addtogroup hipLaunchKernelGGL
|
|
* @{
|
|
* @ingroup KernelTest
|
|
* `void hipLaunchKernelGGL(F kernel, const dim3& numBlocks, const dim3& dimBlocks,
|
|
std::uint32_t sharedMemBytes, hipStream_t stream, Args... args)` -
|
|
* Method to invocate kernel functions
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Test case to check launch bounds via kernel call.
|
|
|
|
* Test source
|
|
* ------------------------
|
|
* - catch/unit/kernel/launch_bounds.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.6
|
|
*/
|
|
|
|
HIP_TEST_CASE(Unit_kernel_LaunchBounds_Functional) {
|
|
size_t Nbytes = N * sizeof(int);
|
|
int *A_d, *C_d, *A_h, *C_h;
|
|
HIPCHECK(hipMalloc(&A_d, Nbytes));
|
|
HIPCHECK(hipMalloc(&C_d, Nbytes));
|
|
|
|
A_h = reinterpret_cast<int*>(malloc(Nbytes));
|
|
C_h = reinterpret_cast<int*>(malloc(Nbytes));
|
|
|
|
for (int i = 0; i < N; i++) {
|
|
A_h[i] = i * 10;
|
|
C_h[i] = 0x0;
|
|
}
|
|
int blocks = N / p_blockSize;
|
|
|
|
HIPCHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
|
|
HIPCHECK(hipGetLastError());
|
|
hipLaunchKernelGGL(myKern, dim3(blocks), dim3(p_blockSize), 0, 0, C_d, A_d, N);
|
|
|
|
#ifdef __HIP_PLATFORM_NVIDIA__
|
|
cudaFuncAttributes attrib;
|
|
cudaFuncGetAttributes(&attrib, myKern);
|
|
printf("binaryVersion = %d\n", attrib.binaryVersion);
|
|
printf("cacheModeCA = %d\n", attrib.cacheModeCA);
|
|
printf("constSizeBytes = %zu\n", attrib.constSizeBytes);
|
|
printf("localSizeBytes = %zud\n", attrib.localSizeBytes);
|
|
printf("maxThreadsPerBlock = %d\n", attrib.maxThreadsPerBlock);
|
|
printf("numRegs = %d\n", attrib.numRegs);
|
|
printf("ptxVersion = %d\n", attrib.ptxVersion);
|
|
printf("sharedSizeBytes = %zud\n", attrib.sharedSizeBytes);
|
|
#endif
|
|
|
|
HIPCHECK(hipDeviceSynchronize());
|
|
HIPCHECK(hipGetLastError());
|
|
HIPCHECK(hipMemcpy(C_h, C_d, Nbytes, hipMemcpyDeviceToHost));
|
|
HIPCHECK(hipDeviceSynchronize());
|
|
|
|
for (int i = 0; i < N; i++) {
|
|
int goldVal = i * 10;
|
|
REQUIRE(C_h[i] == goldVal);
|
|
}
|
|
HIP_CHECK(hipFree(A_d));
|
|
HIP_CHECK(hipFree(C_d));
|
|
free(A_h);
|
|
free(C_h);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group KernelTest.
|
|
* @}
|
|
*/
|